@@ -16,6 +16,7 @@ import inspect
 import os
 import requests
 import json
+import time
 
 # Code zappette
 code_Fb= "35782633"
@@ -69,7 +70,7 @@ class Freebox(IPlugin):
 						if rs['idx'][bar] == '|':
 							log.msg(" bar  :  %s" % (bar))
 							ind1 = rs['idx'][:bar]
-							ind2 = rs['idx'][bar:]
+							ind2 = rs['idx'][bar+1:]
 							log.msg(" ind1  :  %s" % (ind1))
 							log.msg(" ind2  :  %s" % (ind2))
 ##>>> x[2:]
@@ -82,8 +83,10 @@ class Freebox(IPlugin):
 ##'d!'
 ##>>> x[2:-2]
 ##'llo Worl'
-							resp = requests.get ('http://hd2.freebox.fr/pub/remote_control?code=%s&key=%s' % (code_Fb,rs['idx']))
-							log.msg("resp  :  %s" % (resp))
+							resp = requests.get ('http://hd2.freebox.fr/pub/remote_control?code=%s&key=%s' % (code_Fb,ind1))
+							time.sleep(2)		
+							resp = requests.get ('http://hd2.freebox.fr/pub/remote_control?code=%s&key=%s' % (code_Fb,ind2))
+		##					log.msg("resp  :  %s" % (resp))
 				if rs['idx_sec'] == "1":
 					log.msg("*************  'idx_sec'] = 1 ****************")
 					resp = requests.get ('http://hd2.freebox.fr/pub/remote_control?code=%s&key=%s' % (code_Fb,rs['idx']))
